import { BPTree, BPTreeCondition, BPTreeLeafNode, BPTreePair, BPTreeNodeKey, BPTreeUnknownNode, BPTreeConstructorOption } from './base/BPTree';
import { SerializeStrategyAsync } from './SerializeStrategyAsync';
import { ValueComparator } from './base/ValueComparator';
import { SerializableData } from './base/SerializeStrategy';
export declare class BPTreeAsync<K, V> extends BPTree<K, V> {
    protected readonly strategy: SerializeStrategyAsync<K, V>;
    protected readonly nodes: ReturnType<BPTreeAsync<K, V>['_createCachedNode']>;
    constructor(strategy: SerializeStrategyAsync<K, V>, comparator: ValueComparator<V>, option?: BPTreeConstructorOption);
    private _createCachedNode;
    protected getPairsRightToLeft(value: V, startNode: BPTreeLeafNode<K, V>, endNode: BPTreeLeafNode<K, V> | null, comparator: (nodeValue: V, value: V) => boolean): Promise<BPTreePair<K, V>>;
    protected getPairsLeftToRight(value: V, startNode: BPTreeLeafNode<K, V>, endNode: BPTreeLeafNode<K, V> | null, comparator: (nodeValue: V, value: V) => boolean): Promise<BPTreePair<K, V>>;
    protected getPairs(value: V, startNode: BPTreeLeafNode<K, V>, endNode: BPTreeLeafNode<K, V> | null, comparator: (nodeValue: V, value: V) => boolean, direction: 1 | -1): Promise<BPTreePair<K, V>>;
    protected _createNodeId(isLeaf: boolean): Promise<string>;
    protected _createNode(isLeaf: boolean, keys: string[] | K[][], values: V[], leaf?: boolean, parent?: string | null, next?: string | null, prev?: string | null): Promise<BPTreeUnknownNode<K, V>>;
    protected _deleteEntry(node: BPTreeUnknownNode<K, V>, key: BPTreeNodeKey<K>, value: V): Promise<void>;
    protected _insertInParent(node: BPTreeUnknownNode<K, V>, value: V, pointer: BPTreeUnknownNode<K, V>): Promise<void>;
    init(): Promise<void>;
    protected getNode(id: string): Promise<BPTreeUnknownNode<K, V>>;
    protected insertableNode(value: V): Promise<BPTreeLeafNode<K, V>>;
    protected insertableEndNode(value: V, direction: 1 | -1): Promise<BPTreeLeafNode<K, V> | null>;
    protected leftestNode(): Promise<BPTreeLeafNode<K, V>>;
    protected rightestNode(): Promise<BPTreeLeafNode<K, V>>;
    protected commitHeadBuffer(): Promise<void>;
    protected commitNodeCreateBuffer(): Promise<void>;
    protected commitNodeUpdateBuffer(): Promise<void>;
    protected commitNodeDeleteBuffer(): Promise<void>;
    keys(condition: BPTreeCondition<V>, filterValues?: Set<K>): Promise<Set<K>>;
    where(condition: BPTreeCondition<V>): Promise<BPTreePair<K, V>>;
    insert(key: K, value: V): Promise<void>;
    delete(key: K, value: V): Promise<void>;
    exists(key: K, value: V): Promise<boolean>;
    setHeadData(data: SerializableData): Promise<void>;
    forceUpdate(): Promise<number>;
}
