import { BPTree, BPTreeCondition, BPTreeLeafNode, BPTreePair, BPTreeNodeKey, BPTreeUnknownNode, BPTreeConstructorOption } from './base/BPTree';
import { SerializeStrategySync } from './SerializeStrategySync';
import { ValueComparator } from './base/ValueComparator';
import { SerializableData } from './base/SerializeStrategy';
export declare class BPTreeSync<K, V> extends BPTree<K, V> {
    protected readonly strategy: SerializeStrategySync<K, V>;
    protected readonly nodes: ReturnType<BPTreeSync<K, V>['_createCachedNode']>;
    constructor(strategy: SerializeStrategySync<K, V>, comparator: ValueComparator<V>, option?: BPTreeConstructorOption);
    private _createCachedNode;
    protected getPairsRightToLeft(value: V, startNode: BPTreeLeafNode<K, V>, endNode: BPTreeLeafNode<K, V> | null, comparator: (nodeValue: V, value: V) => boolean): BPTreePair<K, V>;
    protected getPairsLeftToRight(value: V, startNode: BPTreeLeafNode<K, V>, endNode: BPTreeLeafNode<K, V> | null, comparator: (nodeValue: V, value: V) => boolean): BPTreePair<K, V>;
    protected getPairs(value: V, startNode: BPTreeLeafNode<K, V>, endNode: BPTreeLeafNode<K, V> | null, comparator: (nodeValue: V, value: V) => boolean, direction: 1 | -1): BPTreePair<K, V>;
    protected _createNodeId(isLeaf: boolean): string;
    protected _createNode(isLeaf: boolean, keys: string[] | K[][], values: V[], leaf?: boolean, parent?: string | null, next?: string | null, prev?: string | null): BPTreeUnknownNode<K, V>;
    protected _deleteEntry(node: BPTreeUnknownNode<K, V>, key: BPTreeNodeKey<K>, value: V): void;
    protected _insertInParent(node: BPTreeUnknownNode<K, V>, value: V, pointer: BPTreeUnknownNode<K, V>): void;
    init(): void;
    protected getNode(id: string): BPTreeUnknownNode<K, V>;
    protected insertableNode(value: V): BPTreeLeafNode<K, V>;
    protected insertableEndNode(value: V, direction: 1 | -1): BPTreeLeafNode<K, V> | null;
    protected leftestNode(): BPTreeLeafNode<K, V>;
    protected rightestNode(): BPTreeLeafNode<K, V>;
    protected commitHeadBuffer(): void;
    protected commitNodeCreateBuffer(): void;
    protected commitNodeUpdateBuffer(): void;
    protected commitNodeDeleteBuffer(): void;
    keys(condition: BPTreeCondition<V>, filterValues?: Set<K>): Set<K>;
    where(condition: BPTreeCondition<V>): BPTreePair<K, V>;
    insert(key: K, value: V): void;
    delete(key: K, value: V): void;
    exists(key: K, value: V): boolean;
    setHeadData(data: SerializableData): void;
    forceUpdate(): number;
}
